"""The version number is based on semantic versioning.

References
- https://semver.org/
- https://www.python.org/dev/peps/pep-0440/

This file is autogenerated, do not modify by hand.
"""
__version__ = "1.0.0-beta.59"
COMMIT = "f85a8b458bb21f20ac3f787c8d7496d5c969dc63"
MAJOR = 1
MINOR = 0
PATCH = 0
